summaryrefslogtreecommitdiffstats
path: root/configdialog/kbfxconfigdlgbutton.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'configdialog/kbfxconfigdlgbutton.ui.h')
-rw-r--r--configdialog/kbfxconfigdlgbutton.ui.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/configdialog/kbfxconfigdlgbutton.ui.h b/configdialog/kbfxconfigdlgbutton.ui.h
index 015b860..0901dd2 100644
--- a/configdialog/kbfxconfigdlgbutton.ui.h
+++ b/configdialog/kbfxconfigdlgbutton.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** Qt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
@@ -12,22 +12,22 @@
void KbfxConfigDlgButton::init()
{
- connect ( this, SIGNAL ( KbfxConfigDlgButtonChanged ( const char *, const QString & ) ),
- this, SLOT ( ChangeForm ( const char *, const QString & ) ) );
+ connect ( this, TQT_SIGNAL ( KbfxConfigDlgButtonChanged ( const char *, const TQString & ) ),
+ this, TQT_SLOT ( ChangeForm ( const char *, const TQString & ) ) );
}
/* actions performed when url is selected */
-void KbfxConfigDlgButton::KbfxURLRequesterNormalUrlSelected ( const QString &selected_img_path )
+void KbfxConfigDlgButton::KbfxURLRequesterNormalUrlSelected ( const TQString &selected_img_path )
{
emit KbfxConfigDlgButtonChanged ( "normal", selected_img_path );
}
-void KbfxConfigDlgButton::KbfxURLRequesterPressedUrlSelected ( const QString &selected_img_path )
+void KbfxConfigDlgButton::KbfxURLRequesterPressedUrlSelected ( const TQString &selected_img_path )
{
emit KbfxConfigDlgButtonChanged ( "pressed", selected_img_path );
}
-void KbfxConfigDlgButton::KbfxURLRequesterHoverUrlSelected ( const QString &selected_img_path )
+void KbfxConfigDlgButton::KbfxURLRequesterHoverUrlSelected ( const TQString &selected_img_path )
{
emit KbfxConfigDlgButtonChanged ( "hover", selected_img_path );
}
@@ -42,16 +42,16 @@ void KbfxConfigDlgButton::KbfxButtonToggled ( bool )
}
/* url processing */
-void KbfxConfigDlgButton::ChangeForm ( const char *name, const QString &path )
+void KbfxConfigDlgButton::ChangeForm ( const char *name, const TQString &path )
{
kdDebug() << "Received: " << name << " + " << path << endl;
- QString tmppath = path;
+ TQString tmppath = path;
if ( tmppath.startsWith ( "file://" ) ) tmppath.remove ( "file://" );
- QImage tmp ( tmppath );
+ TQImage tmp ( tmppath );
- QString tmpname = name;
+ TQString tmpname = name;
if ( tmpname == "pressed" )
{
if ( tmp.isNull() )
@@ -133,7 +133,7 @@ void KbfxConfigDlgButton::ChangeForm()
if ( ConfigInit().m_ToolBarResize == FALSE && KbfxResizeKicker->state() == 2 )
KbfxResizeKicker->toggle();
- KbfxFadeTime->setText ( QString::number ( ConfigInit().m_fadeTime ) );
+ KbfxFadeTime->setText ( TQString::number ( ConfigInit().m_fadeTime ) );
}
@@ -163,7 +163,7 @@ void KbfxConfigDlgButton::KbfxFadeButton_toggled( bool _state )
{
if ( _state )
{
- KbfxFadeTime->setText ( QString::number ( ConfigInit().m_fadeTimeDefault ) );
+ KbfxFadeTime->setText ( TQString::number ( ConfigInit().m_fadeTimeDefault ) );
ConfigInit().m_fadeTime = ConfigInit().m_fadeTimeDefault;
}
else
@@ -179,5 +179,5 @@ void KbfxConfigDlgButton::KbfxFadeTime_lostFocus()
ConfigInit().m_fadeTime = _value;
ConfigInit().checkValues();
- KbfxFadeTime->setText ( QString::number ( ConfigInit().m_fadeTime ) );
+ KbfxFadeTime->setText ( TQString::number ( ConfigInit().m_fadeTime ) );
}
@@ -2,7 +2,7 @@
**
** If you want to add, delete, or rename functions or slots, use
-** Qt Designer to update this file, preserving your code.
+** TQt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.